@@ -187,7 +187,7 @@ class xmlDocPlasma(xmlDoc):
 
 
 class plasma(samba):
-    """Класс для обработки конфигурационного файла типа kde
+    """Класс для обработки конфигурационного файла типа plasma
 
     """
     _comment = "#"
